@@ -6,37 +6,16 @@ package SPVM::Go::Select::Case;
 
 =head1 Name
 
-SPVM::Go::Select::Case - Short Description
+SPVM::Go::Select::Case - Selected Cases
 
 =head1 Description
 
-Go::Select::Case class of L<SPVM> has methods for someting.
+The Go::Select::Case class in L<SPVM> represents selected cases.
 
 =head1 Usage
 
   use Go::Select::Case;
 
-=head1 Fields
-
-
-
-=head1 Class Methods
-
-
-
-=head1 Instance Methods
-
-
-
-
-=head1 Repository
-
-
-
-=head1 Author
-
-Yuki Kimoto C<kimoto.yuki@gmail.com>
-
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
